[ci skip] Fix Effect javadocs (#11182)

This commit is contained in:
Jake Potrebic 2024-08-11 15:35:45 -07:00
parent 4c7b6f5c05
commit 0625ce9d09

View file

@ -10,17 +10,40 @@ index 0000000000000000000000000000000000000000..00000000000000000000000000000000
--- a/src/main/java/org/bukkit/Effect.java
+++ b/src/main/java/org/bukkit/Effect.java
@@ -0,0 +0,0 @@ public enum Effect {
*/
EXTINGUISH(1009, Type.SOUND),
/**
* Sound of a block breaking. Needs block ID as additional info.
- * A song from a record. Needs the record item ID as additional info
+ * A song from a record. Needs the record {@link Material} as additional info.
*/
RECORD_PLAY(1010, Type.SOUND, Material.class),
/**
@@ -0,0 +0,0 @@ public enum Effect {
*/
ZOMBIE_DESTROY_DOOR(1021, Type.SOUND),
/**
* A visual smoke effect. Needs direction as additional info.
*/
SMOKE(2000, Type.VISUAL, BlockFace.class),
/**
* Sound of a block breaking. Needs block ID as additional info.
*/
- STEP_SOUND(2001, Type.SOUND, Material.class),
+ STEP_SOUND(2001, Type.SOUND, org.bukkit.block.data.BlockData.class, Material.class), // Paper - block data is more correct, but the impl of the mtehods will still work with Material
/**
- * Visual effect of a splash potion breaking. Needs potion data value as
+ * Visual effect of a splash potion breaking. Needs color data value as
+ * Visual effect of a splash potion breaking. Needs {@link Color} data value as
* additional info.
*/
POTION_BREAK(2002, Type.VISUAL, Color.class),
/**
- * Visual effect of an instant splash potion breaking. Needs color data
+ * Visual effect of an instant splash potion breaking. Needs {@link Color} data
* value as additional info.
*/
INSTANT_POTION_BREAK(2007, Type.VISUAL, Color.class),
@@ -0,0 +0,0 @@ public enum Effect {
PORTAL_TRAVEL(1032, Type.SOUND),
/**
@ -41,6 +64,15 @@ index 0000000000000000000000000000000000000000..00000000000000000000000000000000
VILLAGER_PLANT_GROW(2005, Type.VISUAL, Integer.class),
/**
* The sound/particles used by the enderdragon's breath
@@ -0,0 +0,0 @@ public enum Effect {
* The particles shown when a lightning hits a lightning rod or oxidized
* copper.
*
- * Data is the axis at which the particle should be shown. If no data is
+ * Data is the {@link Axis} at which the particle should be shown. If no data is
* provided it will show the particles at the block faces.
*/
ELECTRIC_SPARK(3002, Type.VISUAL, Axis.class),
@@ -0,0 +0,0 @@ public enum Effect {
* block.
*/
@ -89,6 +121,9 @@ index 0000000000000000000000000000000000000000..00000000000000000000000000000000
+
+ PARTICLES_SCULK_SHRIEK(3007, Type.SOUND),
+
+ /**
+ * Requires a {@link org.bukkit.block.data.BlockData} param
+ */
+ PARTICLES_AND_SOUND_BRUSH_BLOCK_COMPLETE(3008, Type.VISUAL, org.bukkit.block.data.BlockData.class),
+
+ PARTICLES_EGG_CRACK(3009, Type.VISUAL),
@@ -0,0 +0,0 @@ public enum Effect {
ZOMBIE_DESTROY_DOOR(1021, Type.SOUND),
/**
- * A visual smoke effect. Needs direction as additional info.
+ * A visual smoke effect. Needs a {@link BlockFace} direction as additional info.
*/
SMOKE(2000, Type.VISUAL, BlockFace.class),
@@ -0,0 +0,0 @@ public enum Effect {
SMOKE(2000, Type.VISUAL, BlockFace.class),
/**
- * Sound of a block breaking. Needs block ID as additional info.
+ * Sound of a block breaking. Needs {@link org.bukkit.block.data.BlockData} as additional info.
*/